var ex = {};

(function() {
	var requestAnimationFrame = window.requestAnimationFrame || 
		window.msRequestAnimationFrame ||
		window.mozRequestAnimationFrame ||
		window.webkitRequestAnimationFrame ||
		function(renderFrame) {
			window.setTimeout(renderFrame, 1000 / ex.FPS);
		};;
	window.requestAnimationFrame = requestAnimationFrame;
})();

ex.renderText = function(context, text, size, posX, posY, alignX, alignY) {
	var chars = " abcdefghijklmnopqrstuvwxyz0123456789!?.,:/-'";
	if (alignX === "center") {
		posX -= (text.length * size * 1.2 - size * 0.2) / 2;
	} else if (alignX === "right") {
		posX -= (text.length * size * 1.2 - size * 0.2);
	}
	if (alignY === "center") {
		posY -= size / 2;
	} else if (alignY === "bottom") {
		posY -= size;
	}
	context.imageSmoothingEnabled = false;
	context.mozImageSmoothingEnabled = false;
	context.oImageSmoothingEnabled = false;
	context.webkitImageSmoothingEnabled = false;
	context.msImageSmoothingEnabled = false;
	for (var pos = 0; pos < text.length; pos++) {
		context.drawImage(ex.font, Math.max(0, chars.indexOf(text.charAt(pos).toLowerCase())) * 6, 0, 5, 5, posX + pos * size * 1.2, posY, size, size);
	}
}

ex.getTile = function(x, y) {
	return ((Math.ceil(Math.abs(y) / ex.tiles.ay) * ex.tiles.ay + y) % ex.tiles.ay) * ex.tiles.ax + 
		(Math.ceil(Math.abs(x) / ex.tiles.ax) * ex.tiles.ax + x) % ex.tiles.ax;
}

ex.getAction = function() {
	for (var a = 0; a < ex.actionQueue.length; a++) {
		if (ex.actionQueue[a].t === -1) return a;
	}
	ex.actionQueue.push({a: 0, t: -1, tl: 0, tn: 0});
	return ex.actionQueue.length - 1;
}

ex.update = function(dt) {
	if (ex.keyLeft) ex.cam.x -= dt * 0.5;
	if (ex.keyRight) ex.cam.x += dt * 0.5;
	if (ex.keyUp) ex.cam.y -= dt * 0.5;
	if (ex.keyDown) ex.cam.y += dt * 0.5;

	ex.simtAcc += dt;
	if (ex.simtAcc > ex.simdt) {
		ex.simtAcc -= ex.simdt;
		
		ex.buildings[2].sto = Math.max(0, ex.buildings[2].sto - ex.buildings[4].a * 3);
		ex.buildings[6].sto = Math.max(0, ex.buildings[6].sto - ex.buildings[4].a);
		ex.buildings[5].sto = Math.min(ex.buildings[5].cap, ex.buildings[5].sto + ex.buildings[4].a * 10);
		
		var ws = ex.buildings[2].sto - ex.population / 1000;
		var fs = ex.buildings[5].sto - ex.population / 1000;
		var ps = ex.buildings[6].sto - ex.population / 500;
		
		if (ws > 0 && fs > 0 && ps > 0) {
			if (Math.random() < 0.04) ex.population++;
			if (Math.random() < 0.03) ex.population--;
		} else {
			var pd = Math.min(ws * 500, fs * 100);
			var pd = Math.min(pd, Math.floor(ps * 50 * 0.05));
			ex.population = Math.floor(ex.population + pd);
		}
		ex.buildings[2].sto = Math.max(0, ex.buildings[2].sto - ex.population / 1000);
		ex.buildings[5].sto = Math.max(0, ex.buildings[5].sto - ex.population / 1000);
		ex.buildings[6].sto = Math.max(0, ex.buildings[6].sto - ex.population / 500);
	}
	
	ex.mouse.ao = -1;
	for (var i = 0; i < ex.buildings.length; i++) {
		if (ex.mouse.x > (ex.WIDTH - 9 * ex.tiles.width * 1.5 - 8 * 2) / 2 + i * (ex.tiles.width * 1.5 + 2) &&
			ex.mouse.x < (ex.WIDTH - 9 * ex.tiles.width * 1.5 - 8 * 2) / 2 + i * (ex.tiles.width * 1.5 + 2) + ex.tiles.width * 1.5 &&
			ex.mouse.y > ex.HEIGHT - ex.tiles.height * 2 &&
			ex.mouse.y < ex.HEIGHT - ex.tiles.height * 2 + ex.tiles.height * 1.5) {
			ex.mouse.ao = i;
		}
	}

	
	ex.tiles.mouseover = ex.getTile(Math.floor((ex.mouse.x + ex.cam.x) / ex.tiles.width), 
		Math.floor((ex.mouse.y + ex.cam.y) / ex.tiles.height));
	ex.mouse.s = 0;
	if (ex.mouse.a === 0) {
		var on = 0;
		if (ex.tiles.data[ex.getTile(Math.floor((ex.mouse.x + ex.cam.x) / ex.tiles.width) + 1,
			Math.floor((ex.mouse.y + ex.cam.y) / ex.tiles.height))].s != 0) on++;
		if (ex.tiles.data[ex.getTile(Math.floor((ex.mouse.x + ex.cam.x) / ex.tiles.width) - 1,
			Math.floor((ex.mouse.y + ex.cam.y) / ex.tiles.height))].s != 0) on++;
		if (ex.tiles.data[ex.getTile(Math.floor((ex.mouse.x + ex.cam.x) / ex.tiles.width),
			Math.floor((ex.mouse.y + ex.cam.y) / ex.tiles.height) + 1)].s != 0) on++;
		if (ex.tiles.data[ex.getTile(Math.floor((ex.mouse.x + ex.cam.x) / ex.tiles.width),
			Math.floor((ex.mouse.y + ex.cam.y) / ex.tiles.height) - 1)].s != 0) on++;
		if (on > 0 && ex.tiles.data[ex.tiles.mouseover].a === -1 && ex.tiles.data[ex.tiles.mouseover].t > -1 && ex.tiles.data[ex.tiles.mouseover].s === 0) ex.mouse.s = 1;
	} else {
		var on = 0;
		for (var x = 0; x < ex.buildings[ex.mouse.a].w; x++) {
			for (var y = 0; y < ex.buildings[ex.mouse.a].h; y++) {
				if (ex.tiles.data[ex.getTile(Math.floor((ex.mouse.x + ex.cam.x) / ex.tiles.width) + x,
					Math.floor((ex.mouse.y + ex.cam.y) / ex.tiles.height) + y)].t === -1) on++;
			}
		}
		if (on === ex.buildings[ex.mouse.a].w * ex.buildings[ex.mouse.a].h) ex.mouse.s = 1;
	}
	
	for (var a = 0; a < ex.actionQueue.length; a++) {
		if (ex.actionQueue[a].t > -1) {
			ex.actionQueue[a].tl = Math.max(0, ex.actionQueue[a].tl - dt);
			if (ex.actionQueue[a].tl === 0) {
				if (ex.actionQueue[a].a === 0) {
					if (ex.tiles.types[ex.tiles.data[ex.actionQueue[a].t].t].rsto > -1) {
						ex.buildings[ex.tiles.types[ex.tiles.data[ex.actionQueue[a].t].t].rsto].sto = Math.min(ex.buildings[ex.tiles.types[ex.tiles.data[ex.actionQueue[a].t].t].rsto].cap * ex.buildings[ex.tiles.types[ex.tiles.data[ex.actionQueue[a].t].t].rsto].a, ex.buildings[ex.tiles.types[ex.tiles.data[ex.actionQueue[a].t].t].rsto].sto + ex.tiles.types[ex.tiles.data[ex.actionQueue[a].t].t].res);
					}
					ex.tiles.data[ex.actionQueue[a].t].t = -1;
					ex.tiles.data[ex.actionQueue[a].t].s = -1;
				} else {
					ex.buildings[ex.actionQueue[a].a].a++;
				}
				ex.tiles.data[ex.actionQueue[a].t].a = -1;
				ex.actionQueue[a].t = -1;
			}
		}
	}
}

ex.render = function(context) {
	context.clearRect(0, 0, ex.WIDTH, ex.HEIGHT);
	
	if (ex.population <= 0) {
		context.fillStyle = "#ffffff";
		context.fillRect(0, 120, ex.WIDTH, ex.HEIGHT - 240);
		ex.renderText(context, "extinction", 50, ex.WIDTH / 2, ex.HEIGHT / 2, "center", "center");
		ex.renderText(context, "thankfully it's not reality ...", 10, ex.WIDTH - 10, ex.HEIGHT - 110, "right", "top");
		ex.renderText(context, "yet", 10, ex.WIDTH - 10, ex.HEIGHT - 90, "right", "top");
	} else {
	var camX = Math.floor(ex.cam.x);
	var camY = Math.floor(ex.cam.y);

	var firstY = Math.floor(camY / ex.tiles.height);
	var firstX = Math.floor(camX / ex.tiles.width);
	var tile = 0;
	for (var y = firstY; y < firstY + Math.ceil(ex.HEIGHT / ex.tiles.height) + 1; y++) {
		for (var x = firstX; x < firstX + Math.ceil(ex.WIDTH / ex.tiles.width) + 1; x++) {
			tile = ex.getTile(x, y);
			if (tile >= 0 && tile < ex.tiles.data.length) {
				if (ex.tiles.data[tile].t > -1) {
					context.drawImage(ex.tilesheet, 
						ex.tiles.types[ex.tiles.data[tile].t].t[0] * ex.tiles.width,
						ex.tiles.types[ex.tiles.data[tile].t].t[1] * ex.tiles.height, 
						ex.tiles.width, ex.tiles.height, 
						x * ex.tiles.width - camX, y * ex.tiles.height - camY, 
						ex.tiles.width, ex.tiles.height);
				}
			}
		}
	}

	var tile = 0;
	for (var y = firstY; y < firstY + Math.ceil(ex.HEIGHT / ex.tiles.height) + 1; y++) {
		for (var x = firstX; x < firstX + Math.ceil(ex.WIDTH / ex.tiles.width) + 1; x++) {
			tile = ex.getTile(x, y);
			if (tile >= 0 && tile < ex.tiles.data.length) {
				if (ex.tiles.mouseover === tile && ex.mouse.ao === -1) {
					if (ex.mouse.a === 0) {
						if (ex.mouse.s === 1) {
							context.drawImage(ex.tilesheet, 
								ex.cursor[0] * ex.tiles.width,
								ex.cursor[1] * ex.tiles.height, 
								ex.tiles.width, ex.tiles.height, 
								x * ex.tiles.width - camX, y * ex.tiles.height - camY, 
								ex.tiles.width, ex.tiles.height);
						}
					} else {
						if (ex.mouse.s === 0) {
							context.fillStyle = "rgba(250, 0, 0, 0.4)";
						} else {
							context.fillStyle = "rgba(0, 250, 0, 0.4)";
						}
						context.fillRect(x * ex.tiles.width - camX, y * ex.tiles.height - camY, 
							ex.tiles.width * ex.buildings[ex.mouse.a].w, ex.tiles.height * ex.buildings[ex.mouse.a].h);
					}
				}	

				if (ex.tiles.data[tile].t > -1 && ex.tiles.data[tile].a > -1) {
					var	xOff = (ex.buildings[ex.actionQueue[ex.tiles.data[tile].a].a].w * ex.tiles.width - (ex.tiles.width - 12)) / 2;
					var	yOff = (ex.buildings[ex.actionQueue[ex.tiles.data[tile].a].a].h * ex.tiles.height - 4) / 2;
					context.fillStyle = "rgba(250, 250, 250, 0.4)";
					context.fillRect(x * ex.tiles.width - camX + xOff, y * ex.tiles.height - camY + yOff, 
						ex.tiles.width - 12, 4);
					context.fillStyle = "rgba(250, 250, 250, 1)";
					context.fillRect(x * ex.tiles.width - camX + xOff, y * ex.tiles.height - camY + yOff, 
						Math.ceil((ex.tiles.width - 12) / ex.actionQueue[ex.tiles.data[tile].a].tn * (ex.actionQueue[ex.tiles.data[tile].a].tn - ex.actionQueue[ex.tiles.data[tile].a].tl)), 4);
				}
			}
		}
	}

	for (var i = 0; i < ex.buildings.length; i++) {
		if (ex.mouse.ao === i) {
			context.fillStyle = "rgba(70, 70, 70, 0.9)";
		} else {
			context.fillStyle = "rgba(20, 20, 20, 0.9)";
		}
		context.fillRect((ex.WIDTH - 9 * ex.tiles.width * 1.5 - 8 * 2) / 2 + i * (ex.tiles.width * 1.5 + 2), ex.HEIGHT - ex.tiles.height * 2, ex.tiles.width * 1.5, ex.tiles.height * 1.5);
		if (i === ex.mouse.a) {
			context.strokeStyle = "rgba(250, 250, 250, 0.9)";
			context.lineWidth = "1";
			context.strokeRect((ex.WIDTH - 9 * ex.tiles.width * 1.5 - 8 * 2) / 2 + i * (ex.tiles.width * 1.5 + 2) + 1, ex.HEIGHT - ex.tiles.height * 2 + 1, ex.tiles.width * 1.5 - 2, ex.tiles.height * 1.5 - 2);
		}
		context.drawImage(ex.tilesheet, ex.buildings[i].ft[0] * ex.tiles.width, ex.buildings[i].ft[1] * ex.tiles.height, ex.buildings[i].w * ex.tiles.width, ex.buildings[i].h * ex.tiles.height, (ex.WIDTH - 9 * ex.tiles.width * 1.5 - 8 * 2) / 2 + i * (ex.tiles.width * 1.5 + 2) + 15, ex.HEIGHT - ex.tiles.height * 2 + 12, ex.tiles.width * 1.5 - 30, ex.tiles.height * 1.5 - 30);
		ex.renderText(context, ex.buildings[i].n, 5, (ex.WIDTH - 9 * ex.tiles.width * 1.5 - 8 * 2) / 2 + i * (ex.tiles.width * 1.5 + 2) + ex.tiles.width * 1.5 / 2, ex.HEIGHT - ex.tiles.height + 16, "center", "bottom");
		if (ex.buildings[i].cap * ex.buildings[i].a > 0) {
			context.fillStyle = "rgba(250, 250, 250, 0.4)";
			context.fillRect((ex.WIDTH - 9 * ex.tiles.width * 1.5 - 8 * 2) / 2 + i * (ex.tiles.width * 1.5 + 2) + 15, ex.HEIGHT - ex.tiles.height * 2 + 5, ex.tiles.width - 6, 4);
			context.fillStyle = "rgba(250, 250, 250, 1)";
			context.fillRect((ex.WIDTH - 9 * ex.tiles.width * 1.5 - 8 * 2) / 2 + i * (ex.tiles.width * 1.5 + 2) + 15, ex.HEIGHT - ex.tiles.height * 2 + 5, (ex.tiles.width - 6) / (ex.buildings[i].cap * ex.buildings[i].a) * ex.buildings[i].sto, 4);
		}
	}

	ex.renderText(context, ("pop:" + ex.population), 10, ex.WIDTH - 10, 10, "right", "top");
	}
}

ex.loop = function() {
	var now = Date.now();
	ex.tAcc += Math.min(now - ex.currentMilliSeconds, 5000);
	ex.currentMilliSeconds = now;
	while (ex.tAcc >= ex.dt) {
		ex.update(ex.dt);
		ex.tAcc -= ex.dt;
		ex.t += ex.dt;
	}
	ex.render(ex.gcContext);
	if (ex.population > 0) {
		requestAnimationFrame(ex.loop);
	}
}

ex.init = function() {
	ex.startMilliSeconds = Date.now();
	ex.currentMilliSeconds = ex.startMilliSeconds;

	ex.gc = document.getElementById("gc");
	ex.gcContext = ex.gc.getContext("2d");
	ex.gc.style.background = "#332c24";
	ex.WIDTH = ex.gc.clientWidth;
	ex.HEIGHT = ex.gc.clientHeight;
					
	ex.FPS = 60;
	ex.dt = 10;
	ex.t = 0;
	ex.tAcc = 0;

	ex.keyLeft = false;
	ex.keyRight = false;
	ex.keyUp = false;
	ex.keyDown = false;
	
	ex.tiles = {mouseover: -1, width: 48, height: 48, ax: 512, ay: 512, data: [], types: []};
	ex.tiles.types.push({n: "dirt", t: [0, 0], tn: 5000, rsto: -1, res: -1});
	ex.tiles.types.push({n: "coal", t: [1, 0], tn: 9000, rsto: 6, res: 20});
	ex.tiles.types.push({n: "water", t: [2, 0], tn: 2500, rsto: 2, res: 30});
	ex.tiles.types.push({n: "iron", t: [3, 0], tn: 15000, rsto: 8, res: 20});
	var ttype = 0;
	for (var y = 0; y < ex.tiles.ay; y++) {
		for (var x = 0; x < ex.tiles.ax; x++) {
			ttype = Math.random();
			if (ttype < 0.1) {
				ex.tiles.data.push({t: 1, a: -1, s: 0});
			} else if (ttype < 0.2) {
				ex.tiles.data.push({t: 2, a: -1, s: 0});
			} else if (ttype < 0.3) {
				ex.tiles.data.push({t: 3, a: -1, s: 0});
			} else {
				ex.tiles.data.push({t: 0, a: -1, s: 0});
			}
		}
	}
	ex.tiles.data[1541].t = 6;
	ex.tiles.data[1542].t = 7;
	ex.tiles.data[1543].t = 4;
	ex.tiles.data[1544].t = 15;
	ex.tiles.data[1545].t = 16;
	ex.tiles.data[2053].t = 8;
	ex.tiles.data[2054].t = 9;
	ex.tiles.data[2055].t = 5;
	ex.tiles.data[2056].t = 17;
	ex.tiles.data[2057].t = 18;
	ex.tiles.data[2565].t = 14;
	ex.tiles.data[2566].t = -1;
	ex.tiles.data[2567].t = -1;
	ex.tiles.data[2568].t = -1;
	ex.tiles.data[1541].s = 1;
	ex.tiles.data[1542].s = 1;
	ex.tiles.data[1543].s = 1;
	ex.tiles.data[1544].s = 1;
	ex.tiles.data[1545].s = 1;
	ex.tiles.data[2053].s = 1;
	ex.tiles.data[2054].s = 1;
	ex.tiles.data[2055].s = 1;
	ex.tiles.data[2056].s = 1;
	ex.tiles.data[2057].s = 1;
	ex.tiles.data[2565].s = 1;
	ex.tiles.data[2566].s = -1;
	ex.tiles.data[2567].s = -1;
	ex.tiles.data[2568].s = -1;
	
	ex.cursor = [0, 9];
	
	ex.actionQueue = [];
	
	ex.population = 5000;
	ex.simtAcc = 0;
	ex.simdt = 5000;
	
	ex.buildings = [];
	ex.buildings.push({n: "mine", ft: [0, 9], w: 1, h: 1, a: 0, cap: -1, sto: -1});
	ex.buildings.push({n: "airscrubber", ft: [0, 5], ftl: ex.tiles.types.length, w: 1, h: 1, a: 1, tn: 10000, cap: -1, sto: -1});
	ex.tiles.types.push({n: "airscrubber1", t: [0, 5]});
	ex.buildings.push({n: "watertank", ft: [0, 6], ftl: ex.tiles.types.length, w: 1, h: 1, a: 1, tn: 10000, cap: 100, sto: 80});
	ex.tiles.types.push({n: "watertank1", t: [0, 6]});
	ex.buildings.push({n: "shelter", ft: [0, 3], ftl: ex.tiles.types.length, w: 2, h: 2, a: 1, tn: 10000, cap: 1000, sto: 0});
	ex.tiles.types.push({n: "shelter1", t: [0, 3]});
	ex.tiles.types.push({n: "shelter2", t: [1, 3]});
	ex.tiles.types.push({n: "shelter3", t: [0, 4]});
	ex.tiles.types.push({n: "shelter4", t: [1, 4]});
	ex.buildings.push({n: "greenhouse", ft: [2, 3], ftl: ex.tiles.types.length, w: 2, h: 2, a: 0, tn: 10000, cap: -1, sto: -1});
	ex.tiles.types.push({n: "greenhouse1", t: [2, 3]});
	ex.tiles.types.push({n: "greenhouse2", t: [3, 3]});
	ex.tiles.types.push({n: "greenhouse3", t: [2, 4]});
	ex.tiles.types.push({n: "greenhouse4", t: [3, 4]});
	ex.buildings.push({n: "foodstorage", ft: [1, 5], ftl: ex.tiles.types.length, w: 1, h: 1, a: 1, tn: 10000, cap: 100, sto: 60});
	ex.tiles.types.push({n: "foodstorage1", t: [1, 5]});
	ex.buildings.push({n: "powerplant", ft: [4, 3], ftl: ex.tiles.types.length, w: 2, h: 2, a: 1, tn: 10000, cap: 500, sto: 200});
	ex.tiles.types.push({n: "powerplant1", t: [4, 3]});
	ex.tiles.types.push({n: "powerplant2", t: [5, 3]});
	ex.tiles.types.push({n: "powerplant3", t: [4, 4]});
	ex.tiles.types.push({n: "powerplant4", t: [5, 4]});
	ex.buildings.push({n: "hospital", ft: [1, 6], ftl: ex.tiles.types.length, w: 1, h: 1, a: 0, tn: 10000, cap: -1, sto: -1});
	ex.tiles.types.push({n: "hospital1", t: [1, 6]});
	ex.buildings.push({n: "workshop", ft: [6, 3], ftl: ex.tiles.types.length, w: 2, h: 2, a: 0, tn: 10000, cap: 200, sto: 0});
	ex.tiles.types.push({n: "workshop1", t: [6, 3]});
	ex.tiles.types.push({n: "workshop2", t: [7, 3]});
	ex.tiles.types.push({n: "workshop3", t: [6, 4]});
	ex.tiles.types.push({n: "workshop4", t: [7, 4]});
	
	ex.cam = {x: 0, y: ex.tiles.height};
	ex.mouse = {x: 0, y: 0, a: 0, s: 0, ao: -1};
	
	ex.font = new Image();
	ex.font.src = "https://dl.dropboxusercontent.com/s/0hup633mck0yczr/font.png";
	
	ex.tilesheet = new Image();
	ex.tilesheet.src = "https://dl.dropboxusercontent.com/s/m9z8b4gdugux5u4/tilesheet.png";
	
	requestAnimationFrame(ex.loop);
}

ex.init();

window.onkeydown = function(event) {
	event = event || window.event; 
	switch (event.keyCode) {
		case 37:
		case 65: ex.keyLeft = true; event.preventDefault(); break;
		case 39:
		case 68: ex.keyRight = true; event.preventDefault(); break;
		case 38:
		case 87: ex.keyUp = true; event.preventDefault(); break;
		case 40:
		case 83: ex.keyDown = true; event.preventDefault(); break;
		case 49: ex.mouse.a = 0; break;
		case 50: ex.mouse.a = 1; break;
		case 51: ex.mouse.a = 2; break;
		case 52: ex.mouse.a = 3; break;
		case 53: ex.mouse.a = 4; break;
		case 54: ex.mouse.a = 5; break;
		case 55: ex.mouse.a = 6; break;
		case 56: ex.mouse.a = 7; break;
		case 57: ex.mouse.a = 8; break;
		default: //console.log(event.keyCode);
	}
}

window.onkeyup = function(event) {
	event = event || window.event; 
	switch (event.keyCode) {
		case 37:
		case 65: ex.keyLeft = false; break;
		case 39:
		case 68: ex.keyRight = false; break;
		case 38:
		case 87: ex.keyUp = false; break;
		case 40:
		case 83: ex.keyDown = false; break;
	}
}

ex.gc.onmousedown = function(event) {
	if (ex.mouse.ao > -1) {
		ex.mouse.a = ex.mouse.ao;
	} else if (ex.mouse.s === 1 && ex.tiles.data[ex.tiles.mouseover].a === -1) {
		var a = ex.getAction();
		if (ex.mouse.a === 0) {
			ex.tiles.data[ex.tiles.mouseover].a = a;
			ex.actionQueue[a] = {a: ex.mouse.a, t: ex.tiles.mouseover, tl: ex.tiles.types[ex.tiles.data[ex.tiles.mouseover].t].tn, tn: ex.tiles.types[ex.tiles.data[ex.tiles.mouseover].t].tn};
		} else {
			ex.tiles.data[ex.tiles.mouseover].a = a;
			ex.actionQueue[a] = {a: ex.mouse.a, t: ex.tiles.mouseover, tl: ex.buildings[ex.mouse.a].tn, tn: ex.buildings[ex.mouse.a].tn};
			for (var x = 0; x < ex.buildings[ex.mouse.a].w; x++) {
				for (var y = 0; y < ex.buildings[ex.mouse.a].h; y++) {
					var tile = ex.getTile(Math.floor((ex.mouse.x + ex.cam.x) / ex.tiles.width) + x,
						Math.floor((ex.mouse.y + ex.cam.y) / ex.tiles.height) + y);
					ex.tiles.data[tile].t = ex.buildings[ex.mouse.a].ftl + y * ex.buildings[ex.mouse.a].w + x;
					ex.tiles.data[tile].s = 1;
				}
			}
		}
	}
}

ex.gc.onmouseup = function(event) {
}

ex.gc.onmousemove = function(event) {
	ex.mouse.x = event.pageX - ex.gc.offsetLeft;
	ex.mouse.y = event.pageY - ex.gc.offsetTop;
}